@@ -1,8 +1,7 @@
-import logging
-
 from ._version import __version__
 from .photoinfo import PhotoInfo
 from .photosdb import PhotosDB
+from .photosdb._photosdb_process_comments import CommentInfo, LikeInfo
 from .phototemplate import PhotoTemplate
 from .utils import _debug, _get_logger, _set_debug
 
