@@ -1290,6 +1290,13 @@ def query(
     "exiftool may be installed from https://exiftool.org/.  "
     "Cannot be used with --export-as-hardlink.",
 )
+@click.option(
+    "--ignore-date-modified",
+    is_flag=True,
+    help="If used with --exiftool or --sidecar, will ignore the photo "
+    "modification date and set EXIF:ModifyDate to EXIF:DateTimeOriginal; "
+    "this is consistent with how Photos handles the EXIF:ModifyDate tag.",
+)
 @click.option(
     "--directory",
     metavar="DIRECTORY",
@@ -1389,6 +1396,7 @@ def export(
     download_missing,
     dest,
     exiftool,
+    ignore_date_modified,
     portrait,
     not_portrait,
     screenshot,
@@ -1663,6 +1671,7 @@ def export(
                     use_photos_export=use_photos_export,
                     convert_to_jpeg=convert_to_jpeg,
                     jpeg_quality=jpeg_quality,
+                    ignore_date_modified=ignore_date_modified,
                 )
                 results_exported.extend(results.exported)
                 results_new.extend(results.new)
@@ -1712,6 +1721,7 @@ def export(
                         use_photos_export=use_photos_export,
                         convert_to_jpeg=convert_to_jpeg,
                         jpeg_quality=jpeg_quality,
+                        ignore_date_modified=ignore_date_modified,
                     )
                     results_exported.extend(results.exported)
                     results_new.extend(results.new)
@@ -2218,6 +2228,7 @@ def export_photo(
     use_photos_export=False,
     convert_to_jpeg=False,
     jpeg_quality=1.0,
+    ignore_date_modified=False,
 ):
     """ Helper function for export that does the actual export
 
@@ -2251,6 +2262,7 @@ def export_photo(
         use_photos_export: boolean; if True forces the use of AppleScript to export even if photo not missing
         convert_to_jpeg: boolean; if True, converts non-jpeg images to jpeg
         jpeg_quality: float in range 0.0 <= jpeg_quality <= 1.0.  A value of 1.0 specifies use best quality, a value of 0.0 specifies use maximum compression.
+        ignore_date_modified: if True, sets EXIF:ModifyDate to EXIF:DateTimeOriginal even if date_modified is set
 
     Returns:
         list of path(s) of exported photo or None if photo was missing
@@ -2305,10 +2317,13 @@ def export_photo(
 
         # if download_missing and the photo is missing or path doesn't exist,
         # try to download with Photos
-        use_photos_export = (
-            download_missing and (photo.ismissing or not os.path.exists(photo.path))
-            if not use_photos_export
-            else True
+        use_photos_export = use_photos_export or (
+            download_missing
+            and (
+                photo.ismissing
+                or not os.path.exists(photo.path)
+                or (export_edited and photo.path_edited is None)
+            )
         )
 
         # export the photo to each path in dest_paths
@@ -2339,6 +2354,7 @@ def export_photo(
                     touch_file=touch_file,
                     convert_to_jpeg=convert_to_jpeg,
                     jpeg_quality=jpeg_quality,
+                    ignore_date_modified=ignore_date_modified,
                 )
 
                 results_exported.extend(export_results.exported)
@@ -2400,6 +2416,7 @@ def export_photo(
                         touch_file=touch_file,
                         convert_to_jpeg=convert_to_jpeg,
                         jpeg_quality=jpeg_quality,
+                        ignore_date_modified=ignore_date_modified,
                     )
 
                     results_exported.extend(export_results_edited.exported)
